@@ -17,7 +17,7 @@ from portage.dep import (
 )
 from portage.dep.soname.parse import parse_soname_deps
 from portage.versions import _pkg_str, _unknown_repo
-from portage.eapi import _get_eapi_attrs, eapi_has_use_aliases
+from portage.eapi import _get_eapi_attrs
 from portage.exception import InvalidData, InvalidDependString
 from portage.localization import _
 from _emerge.Task import Task
@@ -63,6 +63,7 @@ class Package(Task):
 
     metadata_keys = [
         "BDEPEND",
+        "BINPKG_FORMAT",
         "BUILD_ID",
         "BUILD_TIME",
         "CHOST",
@@ -135,13 +136,9 @@ class Package(Task):
         # sync metadata with validated repo (may be UNKNOWN_REPO)
         self._metadata["repository"] = self.cpv.repo
 
-        if self.root_config.settings.local_config:
-            implicit_match = db._iuse_implicit_cnstr(self.cpv, self._metadata)
-        else:
-            implicit_match = db._repoman_iuse_implicit_cnstr(self.cpv, self._metadata)
-        usealiases = self.root_config.settings._use_manager.getUseAliases(self)
+        implicit_match = db._iuse_implicit_cnstr(self.cpv, self._metadata)
         self.iuse = self._iuse(
-            self, self._metadata["IUSE"].split(), implicit_match, usealiases, self.eapi
+            self, self._metadata["IUSE"].split(), implicit_match, self.eapi
         )
 
         if (self.iuse.enabled or self.iuse.disabled) and not eapi_attrs.iuse_defaults:
@@ -627,9 +624,6 @@ class Package(Task):
             self._expand_hidden = None
             self._force = None
             self._mask = None
-            if eapi_has_use_aliases(pkg.eapi):
-                for enabled_flag in enabled_flags:
-                    enabled_flags.extend(pkg.iuse.alias_mapping.get(enabled_flag, []))
             self.enabled = frozenset(enabled_flags)
             if pkg.built:
                 # Use IUSE to validate USE settings for built packages,
@@ -737,49 +731,30 @@ class Package(Task):
             "__weakref__",
             "_iuse_implicit_match",
             "_pkg",
-            "alias_mapping",
             "all",
-            "all_aliases",
             "enabled",
             "disabled",
             "tokens",
         )
 
-        def __init__(self, pkg, tokens, iuse_implicit_match, aliases, eapi):
+        def __init__(self, pkg, tokens, iuse_implicit_match, eapi):
             self._pkg = pkg
             self.tokens = tuple(tokens)
             self._iuse_implicit_match = iuse_implicit_match
             enabled = []
             disabled = []
             other = []
-            enabled_aliases = []
-            disabled_aliases = []
-            other_aliases = []
-            aliases_supported = eapi_has_use_aliases(eapi)
-            self.alias_mapping = {}
             for x in tokens:
                 prefix = x[:1]
                 if prefix == "+":
                     enabled.append(x[1:])
-                    if aliases_supported:
-                        self.alias_mapping[x[1:]] = aliases.get(x[1:], [])
-                        enabled_aliases.extend(self.alias_mapping[x[1:]])
                 elif prefix == "-":
                     disabled.append(x[1:])
-                    if aliases_supported:
-                        self.alias_mapping[x[1:]] = aliases.get(x[1:], [])
-                        disabled_aliases.extend(self.alias_mapping[x[1:]])
                 else:
                     other.append(x)
-                    if aliases_supported:
-                        self.alias_mapping[x] = aliases.get(x, [])
-                        other_aliases.extend(self.alias_mapping[x])
-            self.enabled = frozenset(chain(enabled, enabled_aliases))
-            self.disabled = frozenset(chain(disabled, disabled_aliases))
+            self.enabled = frozenset(enabled)
+            self.disabled = frozenset(disabled)
             self.all = frozenset(chain(enabled, disabled, other))
-            self.all_aliases = frozenset(
-                chain(enabled_aliases, disabled_aliases, other_aliases)
-            )
 
         def is_valid_flag(self, flags):
             """
@@ -790,11 +765,7 @@ class Package(Task):
                 flags = [flags]
 
             for flag in flags:
-                if (
-                    not flag in self.all
-                    and not flag in self.all_aliases
-                    and not self._iuse_implicit_match(flag)
-                ):
+                if self.get_flag(flag) is None:
                     return False
             return True
 
@@ -806,27 +777,18 @@ class Package(Task):
                 flags = [flags]
             missing_iuse = []
             for flag in flags:
-                if (
-                    not flag in self.all
-                    and not flag in self.all_aliases
-                    and not self._iuse_implicit_match(flag)
-                ):
+                if self.get_flag(flag) is None:
                     missing_iuse.append(flag)
             return missing_iuse
 
-        def get_real_flag(self, flag):
+        def get_flag(self, flag):
             """
             Returns the flag's name within the scope of this package
-            (accounting for aliases), or None if the flag is unknown.
+            or None if the flag is unknown.
             """
             if flag in self.all:
                 return flag
 
-            if flag in self.all_aliases:
-                for k, v in self.alias_mapping.items():
-                    if flag in v:
-                        return k
-
             if self._iuse_implicit_match(flag):
                 return flag
 
